@@ -12,8 +12,8 @@ listfile="$1"
 src="$2"
 tempdir=${3:-$(mktemp -d)}
 sfx=${4:-/dists}
-# Debian is easy, Ubuntu is bad... no symbolic name. Try to match -security, or one of the latest release names
-testkey=${5:-'updates\|stable\|unstable\|security\|backports\|feisty\|gutsy\|hardy\|intrepid\|jaunty\|karmic\|lucid\|maverick\|depper\|natty\|oneiric\|dapper\|edgy\|precise\|quantal'}
+# Debian is easy, Ubuntu is bad... no symbolic name. Try to match well known release names
+testkey=${5:-'updates\|stable\|unstable\|security\|backports\|feisty\|gutsy\|hardy\|intrepid\|jaunty\|karmic\|lucid\|maverick\|depper\|natty\|oneiric\|dapper\|edgy\|precise\|quantal\|raring\|saucy\|trusty'}
 
 mkdir -p $tempdir
 rm -f $tempdir/url.* $tempdir/log.*
